@@ -13,19 +13,20 @@ class IConfigurable:
     """
      An interface to set configuration parameters to an object.
 
-     It can be added to any existing class by implementing a single <code>configure()</code> method.
+     It can be added to any existing class by implementing a single :func:`configure()` method.
 
-     If you need to emphasis the fact that <code>configure()</code> method can be called multiple times
-     to change object configuration in runtime, use [[IReconfigurable]] interface instead.
+     If you need to emphasis the fact that :func:`configure()` method can be called multiple times
+     to change object configuration in runtime, use :class:`IReconfigurable <pip_services3_commons.config.IReconfigurable.IReconfigurable>` interface instead.
 
      Example:
-         [code]
+
+    .. code-block:: python
+
          class MyClass(IConfigurable):
             _myParam = "default value"
 
          def configure(self, config):
             self._myParam = config.get_as_string_with_default("options.param", myParam)
-         [/code]
     """
 
     def configure(self, config):
