@@ -19,9 +19,12 @@ from .ReferenceException import ReferenceException
 
 class References(IReferences):
     """
-    The most basic implementation of [[IReferences]] to store and locate component references.
+    The most basic implementation of :class:`IReferences <pip_services3_commons.refer.IReferences.IReferences>` to store and locate component references.
 
     Example:
+
+    .. code-block:: python
+
         class MyController(IReferenceable):
             _persistence = None
 
@@ -36,7 +39,7 @@ class References(IReferences):
 
         controller.set_references(references)
 
-            ...
+
     """
 
     _references = None
@@ -83,7 +86,7 @@ class References(IReferences):
         """
         Removes a previously added reference that matches specified locator.
         If many references match the locator, it removes only the first one.
-        When all references shall be removed, use [[removeAll]] method instead.
+        When all references shall be removed, use :func:`remove_all` method instead.
 
         :param locator: a locator to remove reference
 
@@ -185,7 +188,7 @@ class References(IReferences):
 
         :return: a list with matching component references.
 
-        :raises: a [[ReferenceException]] when no references found.
+        :raises: a :class:`ReferenceException <pip_services3_commons.refer.ReferenceException.ReferenceException>` when no references found.
         """
         return self.find(locator, True)
 
@@ -213,7 +216,7 @@ class References(IReferences):
 
          :return: a matching component reference.
 
-         :raises: a [[ReferenceException]] when no references found.
+         :raises: a :class:`ReferenceException <pip_services3_commons.refer.ReferenceException.ReferenceException>` when no references found.
          """
         components = self.find(locator, True)
         return components[0] if len(components) > 0 else None
@@ -229,7 +232,7 @@ class References(IReferences):
 
         :return: a list with matching component references.
 
-        :raises: a [[ReferenceException]] when required is set to true but no references found.
+        :raises: a :class:`ReferenceException <pip_services3_commons.refer.ReferenceException.ReferenceException>` when required is set to true but no references found.
         """
         if locator is None:
             raise Exception("Locator cannot be null")
