@@ -19,10 +19,13 @@ class ValueComparisonRule(IValidationRule):
     Validation rule that compares value to a constant.
 
     Example:
+
+    .. code-block:: python
+    
         schema = Schema().with_rule(ValueComparisonRule("EQ", 1))
 
-        schema.validate(1)          // Result: no errors
-        schema.validate(2)          // Result: 2 is not equal to 1
+        schema.validate(1)          # Result: no errors
+        schema.validate(2)          # Result: 2 is not equal to 1
     """
     _operation = None
     _value = None
